@@ -695,8 +695,8 @@ class RealTimeSignalEnsemblingParalleLauncher():
         y_train_true = full_y_true[starting_train:stopping_train]
         y_train_pred = np.mean(local_rolling_np, axis=1)
         print('finding the best day discretization')
-        print(len(y_train_true))
-        print(len(y_train_pred))
+        print(str(len(y_train_true)))
+        print(str(len(y_train_pred)))
         splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(
             y_train_pred, y_train_true)
         y_next_pred = local_signal_df.values[prediction_index, :].mean()
@@ -719,8 +719,8 @@ class RealTimeSignalEnsemblingParalleLauncher():
         y_train_true = full_y_true[starting_train:stopping_train]
         y_train_pred = np.mean(local_rolling_np, axis=1)
         print('finding the best minute discretization')
-        print(len(y_train_true))
-        print(len(y_train_pred))
+        print(str(len(y_train_true)))
+        print(str(len(y_train_pred)))
         splitting_quantile_threshold, splitting_threshold, sharpe_strat, sharpe_under = signal_utility.find_best_two_states_discretization(y_train_pred, y_train_true)
         y_next_pred = local_signal_df.values[prediction_index, :].mean()
         print('minute continuous prediction '+str(y_next_pred))
